@@ -1,16 +1,18 @@
 # Copyright (c) IPython Development Team.
 # Distributed under the terms of the Modified BSD License.
+from __future__ import annotations
 
 from .application import *
 from .configurable import *
 from .loader import Config
 
-__all__ = [  # noqa
+__all__ = [  # noqa: F405
     "Config",
     "Application",
     "ApplicationError",
     "LevelFormatter",
     "configurable",
+    "Configurable",
     "ConfigurableError",
     "MultipleInstanceError",
     "LoggingConfigurable",
