@@ -1,13 +1,14 @@
 """Useful decorators for Traitlets users."""
+from __future__ import annotations
 
 import copy
 from inspect import Parameter, Signature, signature
-from typing import Type, TypeVar
+from typing import Any, Type, TypeVar
 
 from ..traitlets import HasTraits, Undefined
 
 
-def _get_default(value):
+def _get_default(value: Any) -> Any:
     """Get default argument value, given the trait default value."""
     return Parameter.empty if value == Undefined else value
 
@@ -55,9 +56,7 @@ def signature_has_traits(cls: Type[T]) -> Type[T]:
     # because it can't accept traits as keyword arguments
     if old_var_keyword_parameter is None:
         raise RuntimeError(
-            "The {} constructor does not take **kwargs, which means that the signature can not be expanded with trait names".format(
-                cls
-            )
+            f"The {cls} constructor does not take **kwargs, which means that the signature can not be expanded with trait names"
         )
 
     new_parameters = []
